// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kdebugsettingscore_debug.h"


Q_LOGGING_CATEGORY(KDEBUGSETTINGSCORE_LOG, "log_kdebugsettingscore", QtInfoMsg)

